==> org.wso2.carbon.dataservices.task-4.4.23-sources.jar: org/wso2/carbon/dataservices/task/DSTaskInfo.java <==
/*
 *  Copyright (c) 2005-2011, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 *  WSO2 Inc. licenses this file to you under the Apache License,
 *  Version 2.0 (the "License"); you may not use this file except
 *  in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 *
 */
package org.wso2.carbon.dataservices.task;

import java.util.Calendar;

/**
 * This class represents a data service scheduled task information.
 */
public class DSTaskInfo {

	private String name;
	
	private Calendar startTime;
	
	private Calendar endTime;
	
	private int taskCount;
	
	private int taskInterval;
	
	private String cronExpression;
	
	private String serviceName;
	
	private String operationName;
	
	private String dataTaskClassName;
	
	public DSTaskInfo() {
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Calendar getStartTime() {
		return startTime;
	}

	public void setStartTime(Calendar startTime) {
		this.startTime = startTime;
	}

	public Calendar getEndTime() {
		return endTime;
	}

	public void setEndTime(Calendar endTime) {
		this.endTime = endTime;
	}

	public int getTaskCount() {
		return taskCount;
	}

	public void setTaskCount(int taskCount) {
		this.taskCount = taskCount;
	}

	public int getTaskInterval() {
		return taskInterval;
	}

	public void setTaskInterval(int taskInterval) {
		this.taskInterval = taskInterval;
	}

	public String getServiceName() {
		return serviceName;
	}

	public void setServiceName(String serviceName) {
		this.serviceName = serviceName;
	}

	public String getOperationName() {
		return operationName;
	}

	public void setOperationName(String operationName) {
		this.operationName = operationName;
	}

	public String getCronExpression() {
		return cronExpression;
	}

	public void setCronExpression(String cronExpression) {
		this.cronExpression = cronExpression;
	}

	public String getDataTaskClassName() {
		return dataTaskClassName;
	}

	public void setDataTaskClassName(String dataTaskClassName) {
		this.dataTaskClassName = dataTaskClassName;
	}
	
}

==> org.wso2.carbon.dataservices.task-4.4.95-sources.jar: org/wso2/carbon/dataservices/task/DSTaskInfo.java <==
/*
 *  Copyright (c) 2005-2011, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 *  WSO2 Inc. licenses this file to you under the Apache License,
 *  Version 2.0 (the "License"); you may not use this file except
 *  in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 *
 */
package org.wso2.carbon.dataservices.task;

import java.util.Calendar;

/**
 * This class represents a data service scheduled task information.
 */
public class DSTaskInfo {

	private String name;
	
	private Calendar startTime;
	
	private Calendar endTime;
	
	private int taskCount;
	
	private long taskInterval;
	
	private String cronExpression;
	
	private String serviceName;
	
	private String operationName;
	
	private String dataTaskClassName;
	
	public DSTaskInfo() {
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Calendar getStartTime() {
		return startTime;
	}

	public void setStartTime(Calendar startTime) {
		this.startTime = startTime;
	}

	public Calendar getEndTime() {
		return endTime;
	}

	public void setEndTime(Calendar endTime) {
		this.endTime = endTime;
	}

	public int getTaskCount() {
		return taskCount;
	}

	public void setTaskCount(int taskCount) {
		this.taskCount = taskCount;
	}

	public long getTaskInterval() {
		return taskInterval;
	}

	public void setTaskInterval(long taskInterval) {
		this.taskInterval = taskInterval;
	}

	public String getServiceName() {
		return serviceName;
	}

	public void setServiceName(String serviceName) {
		this.serviceName = serviceName;
	}

	public String getOperationName() {
		return operationName;
	}

	public void setOperationName(String operationName) {
		this.operationName = operationName;
	}

	public String getCronExpression() {
		return cronExpression;
	}

	public void setCronExpression(String cronExpression) {
		this.cronExpression = cronExpression;
	}

	public String getDataTaskClassName() {
		return dataTaskClassName;
	}

	public void setDataTaskClassName(String dataTaskClassName) {
		this.dataTaskClassName = dataTaskClassName;
	}
	
}
